@@ -6,7 +6,8 @@ from pathlib import Path
 import click
 from threedi_api_client.openapi.api.v3_api import V3Api
 import websockets
-from openapi_client import Configuration, ApiException
+from threedi_api_client.api import Configuration
+from threedi_api_client.openapi.exceptions import ApiException
 from rich.table import Table
 from rich import box
 from rich.prompt import Confirm
@@ -72,20 +73,19 @@ def models(ctx: typer.Context):
         )
         for i, model in enumerate(threedi_models.results):
             if model.inp_success is True:
-                txt = f":heavy_check_mark: [bold green]{model.inp_success}[/bold green] "
+                txt = (
+                    f":heavy_check_mark: [bold green]{model.inp_success}[/bold green] "
+                )
             else:
                 txt = f"[bold red]{model.inp_success}[/bold red]"
-            table.add_row(
-                f"{model.id}", f"{model.name}", f"{model.revision_hash}", txt
-            )
+            table.add_row(f"{model.id}", f"{model.name}", f"{model.revision_hash}", txt)
         remaining -= limit
         limit = min(remaining, DEFAULT_PAGER_SIZE)
         console.print(table)
 
 
 @api_app.command()
-def organisations(
-        ctx: typer.Context):
+def organisations(ctx: typer.Context):
     """List available organisations"""
     organisations_api: V3Api = ctx.obj.api_client
     organisations = organisations_api.organisations_list()
@@ -122,12 +122,12 @@ def organisations(
 
 @api_app.command()
 def simulations(
-        ctx: typer.Context,
-        queued: bool = typer.Option(
+    ctx: typer.Context,
+    queued: bool = typer.Option(
         False,
         "--queued",
         help="Show the current queue",
-        )
+    ),
 ):
     """List simulations"""
     simulations_api: V3Api = ctx.obj.api_client
@@ -151,9 +151,7 @@ def simulations(
     while remaining == simulations.count or (
         remaining > 0 and Confirm.ask("Show more?")
     ):
-        simulations = simulations_api.simulations_list(
-            limit=limit, offset=offset
-        )
+        simulations = simulations_api.simulations_list(limit=limit, offset=offset)
         for i, simulation in enumerate(simulations.results):
             status = simulations_api.simulations_status_list(simulation.id)
             if status.name == "finished":
@@ -172,35 +170,33 @@ def simulations(
 
 @api_app.command()
 def settings(
-        ctx: typer.Context,
-        organisation: str = typer.Option(None, help="Unique-id of the organisation to set as default"),
-        scenario_folder: Path = typer.Option(
-            None,
-            dir_okay=True,
-            writable=True,
-            resolve_path=True,
-            help="Specify a the folder for your scenario's.",
-        ),
-        result_folder: Path = typer.Option(
-            None,
-            dir_okay=True,
-            writable=True,
-            resolve_path=True,
-            help="Specify a results folder.",
-        )
+    ctx: typer.Context,
+    organisation: str = typer.Option(
+        None, help="Unique-id of the organisation to set as default"
+    ),
+    scenario_folder: Path = typer.Option(
+        None,
+        dir_okay=True,
+        writable=True,
+        resolve_path=True,
+        help="Specify a the folder for your scenario's.",
+    ),
+    result_folder: Path = typer.Option(
+        None,
+        dir_okay=True,
+        writable=True,
+        resolve_path=True,
+        help="Specify a results folder.",
+    ),
 ):
     """Set default settings"""
-    console.rule(
-        ":wrench: Configuring defaults for the 3Di cli", style="bold blue"
-    )
+    console.rule(":wrench: Configuring defaults for the 3Di cli", style="bold blue")
     console.print(Padding("", (1, 0)))
     if organisation is None:
         console.rule("Please choose an organisation", style="bold blue")
         if (
             ctx.obj.organisation_uuid
-            and Confirm.ask(
-                f"Change current organisation {ctx.obj.organisation_uuid}?"
-            )
+            and Confirm.ask(f"Change current organisation {ctx.obj.organisation_uuid}?")
             or not ctx.obj.organisation_uuid
         ):
             organisations(ctx)
@@ -215,14 +211,13 @@ def settings(
         default_scenario_path = ctx.obj.scenario_folder or Path("./scenarios").resolve()
         print(default_scenario_path)
         scenario_folder = PathPrompt.ask(
-            "Where do you keep your scenario files?",
-            default=default_scenario_path
+            "Where do you keep your scenario files?", default=default_scenario_path
         )
     if not result_folder:
         results_folder_default = ctx.obj.result_folder or Path("./results").resolve()
         result_folder = PathPrompt.ask(
             "Where do you want to store your result files?",
-            default=results_folder_default
+            default=results_folder_default,
         )
     ctx.obj.organisation_uuid = organisation
     ctx.obj.result_folder = result_folder
@@ -234,27 +229,26 @@ def settings(
 
 @api_app.command()
 def run_scenario(
-        ctx: typer.Context,
-        scenario: int = typer.Option(
-            None,
-            help="The ID of the scenario, as returned by the 'scenarios' command. "
-                 "If not provided the scenarios command will be invoked so you can choose an ID"),
-        model: int = typer.Option(
-            None,
-            help="The ID of the model you want to use, as returned by "
-                 "the 'models' command. If not provided the models command will be invoked so you "
-                 "can choose an ID"),
-        organisation: str = typer.Option(
-            None,
-            help="Unique-id of the organisation to set as default"
-        ),
+    ctx: typer.Context,
+    scenario: int = typer.Option(
+        None,
+        help="The ID of the scenario, as returned by the 'scenarios' command. "
+        "If not provided the scenarios command will be invoked so you can choose an ID",
+    ),
+    model: int = typer.Option(
+        None,
+        help="The ID of the model you want to use, as returned by "
+        "the 'models' command. If not provided the models command will be invoked so you "
+        "can choose an ID",
+    ),
+    organisation: str = typer.Option(
+        None, help="Unique-id of the organisation to set as default"
+    ),
 ):
     """Run a scenario"""
     if scenario is None:
         scenarios(ctx)
-        scenario = IntPrompt.ask(
-            "Which scenario do you want to run? ID"
-        )
+        scenario = IntPrompt.ask("Which scenario do you want to run? ID")
 
     scenario_to_run = ctx.obj.scenarios[scenario]["file"]
     parser = ScenarioParser(scenario_to_run)
@@ -264,7 +258,6 @@ def run_scenario(
             models(ctx)
             model = IntPrompt.ask("Which model do you want to run? ID")
 
-    
     if not organisation:
         organisations(ctx)
         organisation = Prompt.ask("Which organisation do you want to use? UUID")
@@ -315,20 +308,18 @@ def run_scenario(
 
 @api_app.command()
 def results(
-        ctx: typer.Context,
-        simulation: int = typer.Option(None, help="ID of the simulation"),
-        folder: Path = typer.Option(
-            None,
-            dir_okay=True,
-            writable=True,
-            resolve_path=True,
-            help="Absolute path to where the files will be stored.",
-        ),
+    ctx: typer.Context,
+    simulation: int = typer.Option(None, help="ID of the simulation"),
+    folder: Path = typer.Option(
+        None,
+        dir_okay=True,
+        writable=True,
+        resolve_path=True,
+        help="Absolute path to where the files will be stored.",
+    ),
 ):
     """Download results of a simulation"""
-    console.rule(
-        ":arrow_heading_down:  Download simulation results", style="bold blue"
-    )
+    console.rule(":arrow_heading_down:  Download simulation results", style="bold blue")
     console.print(Padding("", (1, 0)))
 
     if simulation is None:
@@ -341,7 +332,7 @@ def results(
             result_folder = Path.cwd()
         folder = PathPrompt.ask(
             "Where do you want to store the results files?",
-            default=Path(f"{result_folder}/simulation-{simulation}")
+            default=Path(f"{result_folder}/simulation-{simulation}"),
         )
 
     try:
@@ -367,9 +358,7 @@ def results(
     )
     f = [gridadmin_download]
 
-    result_files = simulations_api.simulations_results_files_list(
-        simulation.id
-    )
+    result_files = simulations_api.simulations_results_files_list(simulation.id)
     for result in result_files.results:
         if result.file.state in ["error", "removed"]:
             console.print(
@@ -388,9 +377,7 @@ def results(
             ":heavy_check_mark: Finished downloading results", style="success"
         )
     else:
-        console.print(
-            ":collision: Not all files could be downloaded", style="error"
-        )
+        console.print(":collision: Not all files could be downloaded", style="error")
 
 
 @api_app.command()
@@ -399,13 +386,9 @@ def login(ctx: typer.Context):
     try:
         configuration = Configuration(ctx.obj.endpoint)
         ctx.obj.credentials_prompt(configuration)
-        console.print(
-            f":unlock: Authenticated as {ctx.obj.username}", style="success"
-        )
+        console.print(f":unlock: Authenticated as {ctx.obj.username}", style="success")
     except ApiException as e:
-        console.print(
-            f":lock: Failed to authenticate: {e.reason}", style="warning"
-        )
+        console.print(f":lock: Failed to authenticate: {e.reason}", style="warning")
         sys.exit(ExitCodes.AUTHENTICATION_FAILED.value)
 
 
