@@ -23,11 +23,13 @@ try:
     from threedi_api_client.auth import (
         get_auth_token,
         refresh_api_key,
+        is_token_usable
     )
 except ImportError:
     from threedi_api_client.threedi_api_client import (
         get_auth_token,
         refresh_api_key,
+        is_token_usable
     )
 
 from threedi_cmd.console import console
@@ -132,9 +134,8 @@ class Settings:
     def __init__(self, endpoint: str = "", websocket_api_version="v3-beta"):
         self._endpoint = EndpointOption[endpoint]
         self.cached_config = CachedConfig.load_from_file(self.config_file)
-        try:
-            refresh_api_key(self.configuration)
-        except ValueError:
+
+        if not is_token_usable(self.access):
             self.credentials_prompt(self.configuration)
 
         self.websocket_settings = WebSocketSettings(
@@ -291,6 +292,7 @@ class Settings:
 
         # Update the settings
         self.username = username
+        self.password = password
         self.access = token.access
         self.refresh = token.refresh
         config.api_key = {"Authorization": token.access, "refresh": token.refresh}
